# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: python_pachyderm/proto/v2/identity/identity.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='python_pachyderm/proto/v2/identity/identity.proto',
  package='identity_v2',
  syntax='proto3',
  serialized_options=b'Z.github.com/pachyderm/pachyderm/v2/src/identity',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1python_pachyderm/proto/v2/identity/identity.proto\x12\x0bidentity_v2\x1a\x1fgoogle/protobuf/timestamp.proto\"M\n\x04User\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x36\n\x12last_authenticated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"?\n\x14IdentityServerConfig\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x17\n\x0fid_token_expiry\x18\x02 \x01(\t\"S\n\x1eSetIdentityServerConfigRequest\x12\x31\n\x06\x63onfig\x18\x01 \x01(\x0b\x32!.identity_v2.IdentityServerConfig\"!\n\x1fSetIdentityServerConfigResponse\" \n\x1eGetIdentityServerConfigRequest\"T\n\x1fGetIdentityServerConfigResponse\x12\x31\n\x06\x63onfig\x18\x01 \x01(\x0b\x32!.identity_v2.IdentityServerConfig\"a\n\x0cIDPConnector\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x15\n\rconfigVersion\x18\x04 \x01(\x03\x12\x12\n\njsonConfig\x18\x05 \x01(\t\"I\n\x19\x43reateIDPConnectorRequest\x12,\n\tconnector\x18\x01 \x01(\x0b\x32\x19.identity_v2.IDPConnector\"\x1c\n\x1a\x43reateIDPConnectorResponse\"I\n\x19UpdateIDPConnectorRequest\x12,\n\tconnector\x18\x01 \x01(\x0b\x32\x19.identity_v2.IDPConnector\"\x1c\n\x1aUpdateIDPConnectorResponse\"\x1a\n\x18ListIDPConnectorsRequest\"J\n\x19ListIDPConnectorsResponse\x12-\n\nconnectors\x18\x01 \x03(\x0b\x32\x19.identity_v2.IDPConnector\"$\n\x16GetIDPConnectorRequest\x12\n\n\x02id\x18\x01 \x01(\t\"G\n\x17GetIDPConnectorResponse\x12,\n\tconnector\x18\x01 \x01(\x0b\x32\x19.identity_v2.IDPConnector\"\'\n\x19\x44\x65leteIDPConnectorRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x1c\n\x1a\x44\x65leteIDPConnectorResponse\"d\n\nOIDCClient\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rredirect_uris\x18\x02 \x03(\t\x12\x15\n\rtrusted_peers\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06secret\x18\x05 \x01(\t\"B\n\x17\x43reateOIDCClientRequest\x12\'\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x17.identity_v2.OIDCClient\"C\n\x18\x43reateOIDCClientResponse\x12\'\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x17.identity_v2.OIDCClient\"\"\n\x14GetOIDCClientRequest\x12\n\n\x02id\x18\x01 \x01(\t\"@\n\x15GetOIDCClientResponse\x12\'\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x17.identity_v2.OIDCClient\"\x18\n\x16ListOIDCClientsRequest\"C\n\x17ListOIDCClientsResponse\x12(\n\x07\x63lients\x18\x01 \x03(\x0b\x32\x17.identity_v2.OIDCClient\"B\n\x17UpdateOIDCClientRequest\x12\'\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x17.identity_v2.OIDCClient\"\x1a\n\x18UpdateOIDCClientResponse\"%\n\x17\x44\x65leteOIDCClientRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteOIDCClientResponse\"\x12\n\x10\x44\x65leteAllRequest\"\x13\n\x11\x44\x65leteAllResponse2\xa7\n\n\x03\x41PI\x12v\n\x17SetIdentityServerConfig\x12+.identity_v2.SetIdentityServerConfigRequest\x1a,.identity_v2.SetIdentityServerConfigResponse\"\x00\x12v\n\x17GetIdentityServerConfig\x12+.identity_v2.GetIdentityServerConfigRequest\x1a,.identity_v2.GetIdentityServerConfigResponse\"\x00\x12g\n\x12\x43reateIDPConnector\x12&.identity_v2.CreateIDPConnectorRequest\x1a\'.identity_v2.CreateIDPConnectorResponse\"\x00\x12g\n\x12UpdateIDPConnector\x12&.identity_v2.UpdateIDPConnectorRequest\x1a\'.identity_v2.UpdateIDPConnectorResponse\"\x00\x12\x64\n\x11ListIDPConnectors\x12%.identity_v2.ListIDPConnectorsRequest\x1a&.identity_v2.ListIDPConnectorsResponse\"\x00\x12^\n\x0fGetIDPConnector\x12#.identity_v2.GetIDPConnectorRequest\x1a$.identity_v2.GetIDPConnectorResponse\"\x00\x12g\n\x12\x44\x65leteIDPConnector\x12&.identity_v2.DeleteIDPConnectorRequest\x1a\'.identity_v2.DeleteIDPConnectorResponse\"\x00\x12\x61\n\x10\x43reateOIDCClient\x12$.identity_v2.CreateOIDCClientRequest\x1a%.identity_v2.CreateOIDCClientResponse\"\x00\x12\x61\n\x10UpdateOIDCClient\x12$.identity_v2.UpdateOIDCClientRequest\x1a%.identity_v2.UpdateOIDCClientResponse\"\x00\x12X\n\rGetOIDCClient\x12!.identity_v2.GetOIDCClientRequest\x1a\".identity_v2.GetOIDCClientResponse\"\x00\x12^\n\x0fListOIDCClients\x12#.identity_v2.ListOIDCClientsRequest\x1a$.identity_v2.ListOIDCClientsResponse\"\x00\x12\x61\n\x10\x44\x65leteOIDCClient\x12$.identity_v2.DeleteOIDCClientRequest\x1a%.identity_v2.DeleteOIDCClientResponse\"\x00\x12L\n\tDeleteAll\x12\x1d.identity_v2.DeleteAllRequest\x1a\x1e.identity_v2.DeleteAllResponse\"\x00\x42\x30Z.github.com/pachyderm/pachyderm/v2/src/identityb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_USER = _descriptor.Descriptor(
  name='User',
  full_name='identity_v2.User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='identity_v2.User.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_authenticated', full_name='identity_v2.User.last_authenticated', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=176,
)


_IDENTITYSERVERCONFIG = _descriptor.Descriptor(
  name='IdentityServerConfig',
  full_name='identity_v2.IdentityServerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='issuer', full_name='identity_v2.IdentityServerConfig.issuer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id_token_expiry', full_name='identity_v2.IdentityServerConfig.id_token_expiry', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=178,
  serialized_end=241,
)


_SETIDENTITYSERVERCONFIGREQUEST = _descriptor.Descriptor(
  name='SetIdentityServerConfigRequest',
  full_name='identity_v2.SetIdentityServerConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='identity_v2.SetIdentityServerConfigRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=326,
)


_SETIDENTITYSERVERCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetIdentityServerConfigResponse',
  full_name='identity_v2.SetIdentityServerConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=361,
)


_GETIDENTITYSERVERCONFIGREQUEST = _descriptor.Descriptor(
  name='GetIdentityServerConfigRequest',
  full_name='identity_v2.GetIdentityServerConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=363,
  serialized_end=395,
)


_GETIDENTITYSERVERCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetIdentityServerConfigResponse',
  full_name='identity_v2.GetIdentityServerConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='identity_v2.GetIdentityServerConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=397,
  serialized_end=481,
)


_IDPCONNECTOR = _descriptor.Descriptor(
  name='IDPConnector',
  full_name='identity_v2.IDPConnector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='identity_v2.IDPConnector.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='identity_v2.IDPConnector.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='identity_v2.IDPConnector.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configVersion', full_name='identity_v2.IDPConnector.configVersion', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jsonConfig', full_name='identity_v2.IDPConnector.jsonConfig', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=483,
  serialized_end=580,
)


_CREATEIDPCONNECTORREQUEST = _descriptor.Descriptor(
  name='CreateIDPConnectorRequest',
  full_name='identity_v2.CreateIDPConnectorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connector', full_name='identity_v2.CreateIDPConnectorRequest.connector', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=582,
  serialized_end=655,
)


_CREATEIDPCONNECTORRESPONSE = _descriptor.Descriptor(
  name='CreateIDPConnectorResponse',
  full_name='identity_v2.CreateIDPConnectorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=657,
  serialized_end=685,
)


_UPDATEIDPCONNECTORREQUEST = _descriptor.Descriptor(
  name='UpdateIDPConnectorRequest',
  full_name='identity_v2.UpdateIDPConnectorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connector', full_name='identity_v2.UpdateIDPConnectorRequest.connector', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=687,
  serialized_end=760,
)


_UPDATEIDPCONNECTORRESPONSE = _descriptor.Descriptor(
  name='UpdateIDPConnectorResponse',
  full_name='identity_v2.UpdateIDPConnectorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=762,
  serialized_end=790,
)


_LISTIDPCONNECTORSREQUEST = _descriptor.Descriptor(
  name='ListIDPConnectorsRequest',
  full_name='identity_v2.ListIDPConnectorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=792,
  serialized_end=818,
)


_LISTIDPCONNECTORSRESPONSE = _descriptor.Descriptor(
  name='ListIDPConnectorsResponse',
  full_name='identity_v2.ListIDPConnectorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connectors', full_name='identity_v2.ListIDPConnectorsResponse.connectors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=820,
  serialized_end=894,
)


_GETIDPCONNECTORREQUEST = _descriptor.Descriptor(
  name='GetIDPConnectorRequest',
  full_name='identity_v2.GetIDPConnectorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='identity_v2.GetIDPConnectorRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=896,
  serialized_end=932,
)


_GETIDPCONNECTORRESPONSE = _descriptor.Descriptor(
  name='GetIDPConnectorResponse',
  full_name='identity_v2.GetIDPConnectorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connector', full_name='identity_v2.GetIDPConnectorResponse.connector', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=934,
  serialized_end=1005,
)


_DELETEIDPCONNECTORREQUEST = _descriptor.Descriptor(
  name='DeleteIDPConnectorRequest',
  full_name='identity_v2.DeleteIDPConnectorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='identity_v2.DeleteIDPConnectorRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1007,
  serialized_end=1046,
)


_DELETEIDPCONNECTORRESPONSE = _descriptor.Descriptor(
  name='DeleteIDPConnectorResponse',
  full_name='identity_v2.DeleteIDPConnectorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1048,
  serialized_end=1076,
)


_OIDCCLIENT = _descriptor.Descriptor(
  name='OIDCClient',
  full_name='identity_v2.OIDCClient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='identity_v2.OIDCClient.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_uris', full_name='identity_v2.OIDCClient.redirect_uris', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trusted_peers', full_name='identity_v2.OIDCClient.trusted_peers', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='identity_v2.OIDCClient.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='identity_v2.OIDCClient.secret', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1078,
  serialized_end=1178,
)


_CREATEOIDCCLIENTREQUEST = _descriptor.Descriptor(
  name='CreateOIDCClientRequest',
  full_name='identity_v2.CreateOIDCClientRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client', full_name='identity_v2.CreateOIDCClientRequest.client', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1180,
  serialized_end=1246,
)


_CREATEOIDCCLIENTRESPONSE = _descriptor.Descriptor(
  name='CreateOIDCClientResponse',
  full_name='identity_v2.CreateOIDCClientResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client', full_name='identity_v2.CreateOIDCClientResponse.client', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1248,
  serialized_end=1315,
)


_GETOIDCCLIENTREQUEST = _descriptor.Descriptor(
  name='GetOIDCClientRequest',
  full_name='identity_v2.GetOIDCClientRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='identity_v2.GetOIDCClientRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1317,
  serialized_end=1351,
)


_GETOIDCCLIENTRESPONSE = _descriptor.Descriptor(
  name='GetOIDCClientResponse',
  full_name='identity_v2.GetOIDCClientResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client', full_name='identity_v2.GetOIDCClientResponse.client', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1353,
  serialized_end=1417,
)


_LISTOIDCCLIENTSREQUEST = _descriptor.Descriptor(
  name='ListOIDCClientsRequest',
  full_name='identity_v2.ListOIDCClientsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1419,
  serialized_end=1443,
)


_LISTOIDCCLIENTSRESPONSE = _descriptor.Descriptor(
  name='ListOIDCClientsResponse',
  full_name='identity_v2.ListOIDCClientsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clients', full_name='identity_v2.ListOIDCClientsResponse.clients', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1445,
  serialized_end=1512,
)


_UPDATEOIDCCLIENTREQUEST = _descriptor.Descriptor(
  name='UpdateOIDCClientRequest',
  full_name='identity_v2.UpdateOIDCClientRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client', full_name='identity_v2.UpdateOIDCClientRequest.client', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1514,
  serialized_end=1580,
)


_UPDATEOIDCCLIENTRESPONSE = _descriptor.Descriptor(
  name='UpdateOIDCClientResponse',
  full_name='identity_v2.UpdateOIDCClientResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1582,
  serialized_end=1608,
)


_DELETEOIDCCLIENTREQUEST = _descriptor.Descriptor(
  name='DeleteOIDCClientRequest',
  full_name='identity_v2.DeleteOIDCClientRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='identity_v2.DeleteOIDCClientRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1610,
  serialized_end=1647,
)


_DELETEOIDCCLIENTRESPONSE = _descriptor.Descriptor(
  name='DeleteOIDCClientResponse',
  full_name='identity_v2.DeleteOIDCClientResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1649,
  serialized_end=1675,
)


_DELETEALLREQUEST = _descriptor.Descriptor(
  name='DeleteAllRequest',
  full_name='identity_v2.DeleteAllRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1677,
  serialized_end=1695,
)


_DELETEALLRESPONSE = _descriptor.Descriptor(
  name='DeleteAllResponse',
  full_name='identity_v2.DeleteAllResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1697,
  serialized_end=1716,
)

_USER.fields_by_name['last_authenticated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SETIDENTITYSERVERCONFIGREQUEST.fields_by_name['config'].message_type = _IDENTITYSERVERCONFIG
_GETIDENTITYSERVERCONFIGRESPONSE.fields_by_name['config'].message_type = _IDENTITYSERVERCONFIG
_CREATEIDPCONNECTORREQUEST.fields_by_name['connector'].message_type = _IDPCONNECTOR
_UPDATEIDPCONNECTORREQUEST.fields_by_name['connector'].message_type = _IDPCONNECTOR
_LISTIDPCONNECTORSRESPONSE.fields_by_name['connectors'].message_type = _IDPCONNECTOR
_GETIDPCONNECTORRESPONSE.fields_by_name['connector'].message_type = _IDPCONNECTOR
_CREATEOIDCCLIENTREQUEST.fields_by_name['client'].message_type = _OIDCCLIENT
_CREATEOIDCCLIENTRESPONSE.fields_by_name['client'].message_type = _OIDCCLIENT
_GETOIDCCLIENTRESPONSE.fields_by_name['client'].message_type = _OIDCCLIENT
_LISTOIDCCLIENTSRESPONSE.fields_by_name['clients'].message_type = _OIDCCLIENT
_UPDATEOIDCCLIENTREQUEST.fields_by_name['client'].message_type = _OIDCCLIENT
DESCRIPTOR.message_types_by_name['User'] = _USER
DESCRIPTOR.message_types_by_name['IdentityServerConfig'] = _IDENTITYSERVERCONFIG
DESCRIPTOR.message_types_by_name['SetIdentityServerConfigRequest'] = _SETIDENTITYSERVERCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetIdentityServerConfigResponse'] = _SETIDENTITYSERVERCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['GetIdentityServerConfigRequest'] = _GETIDENTITYSERVERCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetIdentityServerConfigResponse'] = _GETIDENTITYSERVERCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['IDPConnector'] = _IDPCONNECTOR
DESCRIPTOR.message_types_by_name['CreateIDPConnectorRequest'] = _CREATEIDPCONNECTORREQUEST
DESCRIPTOR.message_types_by_name['CreateIDPConnectorResponse'] = _CREATEIDPCONNECTORRESPONSE
DESCRIPTOR.message_types_by_name['UpdateIDPConnectorRequest'] = _UPDATEIDPCONNECTORREQUEST
DESCRIPTOR.message_types_by_name['UpdateIDPConnectorResponse'] = _UPDATEIDPCONNECTORRESPONSE
DESCRIPTOR.message_types_by_name['ListIDPConnectorsRequest'] = _LISTIDPCONNECTORSREQUEST
DESCRIPTOR.message_types_by_name['ListIDPConnectorsResponse'] = _LISTIDPCONNECTORSRESPONSE
DESCRIPTOR.message_types_by_name['GetIDPConnectorRequest'] = _GETIDPCONNECTORREQUEST
DESCRIPTOR.message_types_by_name['GetIDPConnectorResponse'] = _GETIDPCONNECTORRESPONSE
DESCRIPTOR.message_types_by_name['DeleteIDPConnectorRequest'] = _DELETEIDPCONNECTORREQUEST
DESCRIPTOR.message_types_by_name['DeleteIDPConnectorResponse'] = _DELETEIDPCONNECTORRESPONSE
DESCRIPTOR.message_types_by_name['OIDCClient'] = _OIDCCLIENT
DESCRIPTOR.message_types_by_name['CreateOIDCClientRequest'] = _CREATEOIDCCLIENTREQUEST
DESCRIPTOR.message_types_by_name['CreateOIDCClientResponse'] = _CREATEOIDCCLIENTRESPONSE
DESCRIPTOR.message_types_by_name['GetOIDCClientRequest'] = _GETOIDCCLIENTREQUEST
DESCRIPTOR.message_types_by_name['GetOIDCClientResponse'] = _GETOIDCCLIENTRESPONSE
DESCRIPTOR.message_types_by_name['ListOIDCClientsRequest'] = _LISTOIDCCLIENTSREQUEST
DESCRIPTOR.message_types_by_name['ListOIDCClientsResponse'] = _LISTOIDCCLIENTSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateOIDCClientRequest'] = _UPDATEOIDCCLIENTREQUEST
DESCRIPTOR.message_types_by_name['UpdateOIDCClientResponse'] = _UPDATEOIDCCLIENTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteOIDCClientRequest'] = _DELETEOIDCCLIENTREQUEST
DESCRIPTOR.message_types_by_name['DeleteOIDCClientResponse'] = _DELETEOIDCCLIENTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllRequest'] = _DELETEALLREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllResponse'] = _DELETEALLRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.User)
  })
_sym_db.RegisterMessage(User)

IdentityServerConfig = _reflection.GeneratedProtocolMessageType('IdentityServerConfig', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYSERVERCONFIG,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.IdentityServerConfig)
  })
_sym_db.RegisterMessage(IdentityServerConfig)

SetIdentityServerConfigRequest = _reflection.GeneratedProtocolMessageType('SetIdentityServerConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETIDENTITYSERVERCONFIGREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.SetIdentityServerConfigRequest)
  })
_sym_db.RegisterMessage(SetIdentityServerConfigRequest)

SetIdentityServerConfigResponse = _reflection.GeneratedProtocolMessageType('SetIdentityServerConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETIDENTITYSERVERCONFIGRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.SetIdentityServerConfigResponse)
  })
_sym_db.RegisterMessage(SetIdentityServerConfigResponse)

GetIdentityServerConfigRequest = _reflection.GeneratedProtocolMessageType('GetIdentityServerConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETIDENTITYSERVERCONFIGREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.GetIdentityServerConfigRequest)
  })
_sym_db.RegisterMessage(GetIdentityServerConfigRequest)

GetIdentityServerConfigResponse = _reflection.GeneratedProtocolMessageType('GetIdentityServerConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETIDENTITYSERVERCONFIGRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.GetIdentityServerConfigResponse)
  })
_sym_db.RegisterMessage(GetIdentityServerConfigResponse)

IDPConnector = _reflection.GeneratedProtocolMessageType('IDPConnector', (_message.Message,), {
  'DESCRIPTOR' : _IDPCONNECTOR,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.IDPConnector)
  })
_sym_db.RegisterMessage(IDPConnector)

CreateIDPConnectorRequest = _reflection.GeneratedProtocolMessageType('CreateIDPConnectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEIDPCONNECTORREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.CreateIDPConnectorRequest)
  })
_sym_db.RegisterMessage(CreateIDPConnectorRequest)

CreateIDPConnectorResponse = _reflection.GeneratedProtocolMessageType('CreateIDPConnectorResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEIDPCONNECTORRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.CreateIDPConnectorResponse)
  })
_sym_db.RegisterMessage(CreateIDPConnectorResponse)

UpdateIDPConnectorRequest = _reflection.GeneratedProtocolMessageType('UpdateIDPConnectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEIDPCONNECTORREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.UpdateIDPConnectorRequest)
  })
_sym_db.RegisterMessage(UpdateIDPConnectorRequest)

UpdateIDPConnectorResponse = _reflection.GeneratedProtocolMessageType('UpdateIDPConnectorResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEIDPCONNECTORRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.UpdateIDPConnectorResponse)
  })
_sym_db.RegisterMessage(UpdateIDPConnectorResponse)

ListIDPConnectorsRequest = _reflection.GeneratedProtocolMessageType('ListIDPConnectorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTIDPCONNECTORSREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.ListIDPConnectorsRequest)
  })
_sym_db.RegisterMessage(ListIDPConnectorsRequest)

ListIDPConnectorsResponse = _reflection.GeneratedProtocolMessageType('ListIDPConnectorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTIDPCONNECTORSRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.ListIDPConnectorsResponse)
  })
_sym_db.RegisterMessage(ListIDPConnectorsResponse)

GetIDPConnectorRequest = _reflection.GeneratedProtocolMessageType('GetIDPConnectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETIDPCONNECTORREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.GetIDPConnectorRequest)
  })
_sym_db.RegisterMessage(GetIDPConnectorRequest)

GetIDPConnectorResponse = _reflection.GeneratedProtocolMessageType('GetIDPConnectorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETIDPCONNECTORRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.GetIDPConnectorResponse)
  })
_sym_db.RegisterMessage(GetIDPConnectorResponse)

DeleteIDPConnectorRequest = _reflection.GeneratedProtocolMessageType('DeleteIDPConnectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEIDPCONNECTORREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.DeleteIDPConnectorRequest)
  })
_sym_db.RegisterMessage(DeleteIDPConnectorRequest)

DeleteIDPConnectorResponse = _reflection.GeneratedProtocolMessageType('DeleteIDPConnectorResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEIDPCONNECTORRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.DeleteIDPConnectorResponse)
  })
_sym_db.RegisterMessage(DeleteIDPConnectorResponse)

OIDCClient = _reflection.GeneratedProtocolMessageType('OIDCClient', (_message.Message,), {
  'DESCRIPTOR' : _OIDCCLIENT,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.OIDCClient)
  })
_sym_db.RegisterMessage(OIDCClient)

CreateOIDCClientRequest = _reflection.GeneratedProtocolMessageType('CreateOIDCClientRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEOIDCCLIENTREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.CreateOIDCClientRequest)
  })
_sym_db.RegisterMessage(CreateOIDCClientRequest)

CreateOIDCClientResponse = _reflection.GeneratedProtocolMessageType('CreateOIDCClientResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEOIDCCLIENTRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.CreateOIDCClientResponse)
  })
_sym_db.RegisterMessage(CreateOIDCClientResponse)

GetOIDCClientRequest = _reflection.GeneratedProtocolMessageType('GetOIDCClientRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOIDCCLIENTREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.GetOIDCClientRequest)
  })
_sym_db.RegisterMessage(GetOIDCClientRequest)

GetOIDCClientResponse = _reflection.GeneratedProtocolMessageType('GetOIDCClientResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETOIDCCLIENTRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.GetOIDCClientResponse)
  })
_sym_db.RegisterMessage(GetOIDCClientResponse)

ListOIDCClientsRequest = _reflection.GeneratedProtocolMessageType('ListOIDCClientsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTOIDCCLIENTSREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.ListOIDCClientsRequest)
  })
_sym_db.RegisterMessage(ListOIDCClientsRequest)

ListOIDCClientsResponse = _reflection.GeneratedProtocolMessageType('ListOIDCClientsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTOIDCCLIENTSRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.ListOIDCClientsResponse)
  })
_sym_db.RegisterMessage(ListOIDCClientsResponse)

UpdateOIDCClientRequest = _reflection.GeneratedProtocolMessageType('UpdateOIDCClientRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEOIDCCLIENTREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.UpdateOIDCClientRequest)
  })
_sym_db.RegisterMessage(UpdateOIDCClientRequest)

UpdateOIDCClientResponse = _reflection.GeneratedProtocolMessageType('UpdateOIDCClientResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEOIDCCLIENTRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.UpdateOIDCClientResponse)
  })
_sym_db.RegisterMessage(UpdateOIDCClientResponse)

DeleteOIDCClientRequest = _reflection.GeneratedProtocolMessageType('DeleteOIDCClientRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEOIDCCLIENTREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.DeleteOIDCClientRequest)
  })
_sym_db.RegisterMessage(DeleteOIDCClientRequest)

DeleteOIDCClientResponse = _reflection.GeneratedProtocolMessageType('DeleteOIDCClientResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEOIDCCLIENTRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.DeleteOIDCClientResponse)
  })
_sym_db.RegisterMessage(DeleteOIDCClientResponse)

DeleteAllRequest = _reflection.GeneratedProtocolMessageType('DeleteAllRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALLREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.DeleteAllRequest)
  })
_sym_db.RegisterMessage(DeleteAllRequest)

DeleteAllResponse = _reflection.GeneratedProtocolMessageType('DeleteAllResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALLRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.identity.identity_pb2'
  # @@protoc_insertion_point(class_scope:identity_v2.DeleteAllResponse)
  })
_sym_db.RegisterMessage(DeleteAllResponse)


DESCRIPTOR._options = None

_API = _descriptor.ServiceDescriptor(
  name='API',
  full_name='identity_v2.API',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1719,
  serialized_end=3038,
  methods=[
  _descriptor.MethodDescriptor(
    name='SetIdentityServerConfig',
    full_name='identity_v2.API.SetIdentityServerConfig',
    index=0,
    containing_service=None,
    input_type=_SETIDENTITYSERVERCONFIGREQUEST,
    output_type=_SETIDENTITYSERVERCONFIGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetIdentityServerConfig',
    full_name='identity_v2.API.GetIdentityServerConfig',
    index=1,
    containing_service=None,
    input_type=_GETIDENTITYSERVERCONFIGREQUEST,
    output_type=_GETIDENTITYSERVERCONFIGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateIDPConnector',
    full_name='identity_v2.API.CreateIDPConnector',
    index=2,
    containing_service=None,
    input_type=_CREATEIDPCONNECTORREQUEST,
    output_type=_CREATEIDPCONNECTORRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateIDPConnector',
    full_name='identity_v2.API.UpdateIDPConnector',
    index=3,
    containing_service=None,
    input_type=_UPDATEIDPCONNECTORREQUEST,
    output_type=_UPDATEIDPCONNECTORRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListIDPConnectors',
    full_name='identity_v2.API.ListIDPConnectors',
    index=4,
    containing_service=None,
    input_type=_LISTIDPCONNECTORSREQUEST,
    output_type=_LISTIDPCONNECTORSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetIDPConnector',
    full_name='identity_v2.API.GetIDPConnector',
    index=5,
    containing_service=None,
    input_type=_GETIDPCONNECTORREQUEST,
    output_type=_GETIDPCONNECTORRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteIDPConnector',
    full_name='identity_v2.API.DeleteIDPConnector',
    index=6,
    containing_service=None,
    input_type=_DELETEIDPCONNECTORREQUEST,
    output_type=_DELETEIDPCONNECTORRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateOIDCClient',
    full_name='identity_v2.API.CreateOIDCClient',
    index=7,
    containing_service=None,
    input_type=_CREATEOIDCCLIENTREQUEST,
    output_type=_CREATEOIDCCLIENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateOIDCClient',
    full_name='identity_v2.API.UpdateOIDCClient',
    index=8,
    containing_service=None,
    input_type=_UPDATEOIDCCLIENTREQUEST,
    output_type=_UPDATEOIDCCLIENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOIDCClient',
    full_name='identity_v2.API.GetOIDCClient',
    index=9,
    containing_service=None,
    input_type=_GETOIDCCLIENTREQUEST,
    output_type=_GETOIDCCLIENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOIDCClients',
    full_name='identity_v2.API.ListOIDCClients',
    index=10,
    containing_service=None,
    input_type=_LISTOIDCCLIENTSREQUEST,
    output_type=_LISTOIDCCLIENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteOIDCClient',
    full_name='identity_v2.API.DeleteOIDCClient',
    index=11,
    containing_service=None,
    input_type=_DELETEOIDCCLIENTREQUEST,
    output_type=_DELETEOIDCCLIENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAll',
    full_name='identity_v2.API.DeleteAll',
    index=12,
    containing_service=None,
    input_type=_DELETEALLREQUEST,
    output_type=_DELETEALLRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_API)

DESCRIPTOR.services_by_name['API'] = _API

# @@protoc_insertion_point(module_scope)



from python_pachyderm.service import Service


class IdentityMixin:
    def set_identity_server_config(self, config):
        """
        Configure the embedded identity server.

        Params:

        * `issuer`: The issuer for the identity server.
        """
        self._req(Service.IDENTITY, "SetIdentityServerConfig", config=config)

    def get_identity_server_config(self):
        """
        Get the embedded identity server configuration
        """
        return self._req(Service.IDENTITY, "GetIdentityServerConfig")

    def create_idp_connector(self, connector):
        """
        Create an IDP connector in the identity server.
        """
        self._req(Service.IDENTITY, "CreateIDPConnector", connector=connector)

    def list_idp_connectors(self):
        """
        List IDP connectors in the identity server.
        """
        return self._req(Service.IDENTITY, "ListIDPConnectors")

    def update_idp_connector(self, connector):
        """
        Update an IDP connector in the identity server.
        """
        self._req(Service.IDENTITY, "UpdateIDPConnector", connector=connector)

    def get_idp_connector(self, id):
        """
        Get an IDP connector in the identity server.
        """
        return self._req(Service.IDENTITY, "GetIDPConnector", id=id)

    def delete_idp_connector(self, id):
        """
        Delete an IDP connector in the identity server.
        """
        self._req(Service.IDENTITY, "DeleteIDPConnector", id=id)

    def create_oidc_client(self, client):
        """
        Create an OIDC client in the identity server.
        """
        return self._req(Service.IDENTITY, "CreateOIDCClient", client=client)

    def update_oidc_client(self, client):
        """
        Update an OIDC client in the identity server.
        """
        return self._req(Service.IDENTITY, "UpdateOIDCClient", client=client)

    def get_oidc_client(self, id):
        """
        Get an OIDC client in the identity server.
        """
        return self._req(Service.IDENTITY, "GetOIDCClient", id=id)

    def delete_oidc_client(self, id):
        """
        Delete an OIDC client in the identity server.
        """
        self._req(Service.IDENTITY, "DeleteOIDCClient", id=id)

    def list_oidc_clients(self):
        """
        List OIDC clients in the identity server.
        """
        return self._req(Service.IDENTITY, "ListOIDCClients")

    def delete_all_identity(self):
        """
        Delete all identity service information.
        """
        self._req(Service.IDENTITY, "DeleteAll")



import os

from google.protobuf import json_format

from python_pachyderm import Client
from python_pachyderm.proto.v2.pps.pps_pb2 import CreatePipelineRequest


def put_files(client: Client, source_path, commit, dest_path, **kwargs):
    """
    Utility function for inserting files from the local `source_path`
    to pachyderm. Roughly equivalent to `pachctl put file [-r]`.

    Params:

    * `client`: The `Client` instance to use.
    * `source_path`: The file/directory to recursively insert content from.
    * `commit`: The `Commit` object to use for inserting files.
    * `dest_path`: The destination path in PFS.
    * `kwargs`: Keyword arguments to forward. See
    `PutFileClient.put_file_from_fileobj` for details.
    """

    with client.modify_file_client(commit) as pfc:
        if os.path.isfile(source_path):
            pfc.put_file_from_filepath(dest_path, source_path, **kwargs)
        elif os.path.isdir(source_path):
            for root, _, filenames in os.walk(source_path):
                for filename in filenames:
                    source_filepath = os.path.join(root, filename)
                    dest_filepath = os.path.join(
                        dest_path, os.path.relpath(source_filepath, start=source_path)
                    )
                    pfc.put_file_from_filepath(dest_filepath, source_filepath, **kwargs)
        else:
            raise Exception("Please provide an existing directory or file")


def parse_json_pipeline_spec(j):
    """
    Parses a string of JSON into a `CreatePipelineRequest` protobuf.
    """
    return json_format.Parse(j, CreatePipelineRequest())


def parse_dict_pipeline_spec(d):
    """
    Parses a dict of serialized JSON into a `CreatePipelineRequest` protobuf.
    """
    return json_format.ParseDict(d, CreatePipelineRequest())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: python_pachyderm/proto/v2/admin/admin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='python_pachyderm/proto/v2/admin/admin.proto',
  package='admin_v2',
  syntax='proto3',
  serialized_options=b'Z+github.com/pachyderm/pachyderm/v2/src/admin',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+python_pachyderm/proto/v2/admin/admin.proto\x12\x08\x61\x64min_v2\x1a\x1bgoogle/protobuf/empty.proto\"0\n\x0b\x43lusterInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rdeployment_id\x18\x02 \x01(\t2H\n\x03\x41PI\x12\x41\n\x0eInspectCluster\x12\x16.google.protobuf.Empty\x1a\x15.admin_v2.ClusterInfo\"\x00\x42-Z+github.com/pachyderm/pachyderm/v2/src/adminb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_CLUSTERINFO = _descriptor.Descriptor(
  name='ClusterInfo',
  full_name='admin_v2.ClusterInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='admin_v2.ClusterInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deployment_id', full_name='admin_v2.ClusterInfo.deployment_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=134,
)

DESCRIPTOR.message_types_by_name['ClusterInfo'] = _CLUSTERINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClusterInfo = _reflection.GeneratedProtocolMessageType('ClusterInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERINFO,
  '__module__' : 'python_pachyderm.proto.v2.admin.admin_pb2'
  # @@protoc_insertion_point(class_scope:admin_v2.ClusterInfo)
  })
_sym_db.RegisterMessage(ClusterInfo)


DESCRIPTOR._options = None

_API = _descriptor.ServiceDescriptor(
  name='API',
  full_name='admin_v2.API',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=136,
  serialized_end=208,
  methods=[
  _descriptor.MethodDescriptor(
    name='InspectCluster',
    full_name='admin_v2.API.InspectCluster',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CLUSTERINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_API)

DESCRIPTOR.services_by_name['API'] = _API

# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python

"""Tests for PPS-related functionality."""

import time

import pytest

import python_pachyderm
from python_pachyderm.service import pps_proto
from tests import util


class Sandbox:
    def __init__(self, test_name):
        client = python_pachyderm.Client()
        client.delete_all()
        commit, input_repo_name, pipeline_repo_name = util.create_test_pipeline(
            client, test_name
        )
        self.client = client
        self.commit = commit
        self.input_repo_name = input_repo_name
        self.pipeline_repo_name = pipeline_repo_name

    def wait(self):
        return self.client.wait_commit(self.commit.id)[0].commit.id


def test_list_subjob():
    sandbox = Sandbox("list_subjob")
    sandbox.wait()

    jobs = list(sandbox.client.list_job())
    assert len(jobs) >= 1

    jobs = list(sandbox.client.list_job(pipeline_name=sandbox.pipeline_repo_name))
    assert len(jobs) >= 1

    jobs = list(
        sandbox.client.list_job(
            pipeline_name=sandbox.pipeline_repo_name,
            input_commit=(sandbox.input_repo_name, sandbox.commit.id),
        )
    )
    assert len(jobs) >= 1


def test_list_job():
    sandbox = Sandbox("list_job1")
    sandbox.wait()
    client = sandbox.client

    commit, _, _ = util.create_test_pipeline(client, "list_job2")
    client.wait_commit(commit.id)

    jobs = list(client.list_job())
    assert len(jobs) == 4


def test_inspect_subjob():
    sandbox = Sandbox("inspect_subjob")
    job_id = sandbox.wait()

    job_info = list(sandbox.client.inspect_job(job_id, sandbox.pipeline_repo_name))
    assert job_info[0].job.id == job_id


def test_inspect_job():
    sandbox = Sandbox("inspect_job1")
    sandbox.wait()
    client = sandbox.client

    commit, _, _ = util.create_test_pipeline(client, "inspect_job2")
    client.wait_commit(commit.id)

    jobs = list(client.list_job())
    job1 = list(client.inspect_job(job_id=jobs[0].job_set.id))

    assert job1[0].job.id == commit.id
    assert len(jobs) == 4


def test_stop_job():
    sandbox = Sandbox("stop_job")
    pipeline_name = sandbox.pipeline_repo_name
    job_id = sandbox.wait()

    sandbox.client.stop_job(job_id, pipeline_name)
    # This is necessary because `StopJob` does not wait for the job to be
    # killed before returning a result.
    # TODO: remove once this is fixed:
    # https://github.com/pachyderm/pachyderm/issues/3856
    time.sleep(1)
    job_info = list(sandbox.client.inspect_job(job_id, pipeline_name))
    # We race to stop the job before it finishes - if we lose the race, it will
    # be in state JOB_SUCCESS
    assert job_info[0].state in [
        pps_proto.JobState.JOB_KILLED,
        pps_proto.JobState.JOB_SUCCESS,
    ]


def test_delete_job():
    sandbox = Sandbox("delete_job")
    job_id = sandbox.wait()
    orig_job_count = len(list(sandbox.client.list_job()))
    sandbox.client.delete_job(job_id, sandbox.pipeline_repo_name)
    jobs = len(list(sandbox.client.list_job()))
    assert jobs == orig_job_count - 1


def test_datums():
    sandbox = Sandbox("datums")
    pipeline_name = sandbox.pipeline_repo_name
    job_id = sandbox.wait()

    # flush the job so it fully finishes
    list(sandbox.client.wait_commit(sandbox.commit.id))

    datums = list(sandbox.client.list_datum(pipeline_name, job_id))
    assert len(datums) == 1
    datum = sandbox.client.inspect_datum(pipeline_name, job_id, datums[0].datum.id)
    assert datum.state == pps_proto.DatumState.SUCCESS

    with pytest.raises(
        python_pachyderm.RpcError,
        match=r"datum matching filter \[.*\] could not be found for job ID {}".format(
            job_id
        ),
    ):
        sandbox.client.restart_datum(pipeline_name, job_id)


def test_inspect_pipeline():
    sandbox = Sandbox("inspect_pipeline")
    pipeline = list(sandbox.client.inspect_pipeline(sandbox.pipeline_repo_name))[0]
    assert pipeline.pipeline.name == sandbox.pipeline_repo_name
    pipelines = list(
        sandbox.client.inspect_pipeline(sandbox.pipeline_repo_name, history=-1)
    )
    assert sandbox.pipeline_repo_name in [p.pipeline.name for p in pipelines]


def test_list_pipeline():
    sandbox = Sandbox("list_pipeline")
    pipelines = list(sandbox.client.list_pipeline())
    assert sandbox.pipeline_repo_name in [p.pipeline.name for p in pipelines]
    pipelines = list(sandbox.client.list_pipeline(history=-1))
    assert sandbox.pipeline_repo_name in [p.pipeline.name for p in pipelines]


def test_delete_pipeline():
    sandbox = Sandbox("delete_pipeline")
    orig_pipeline_count = len(list(sandbox.client.list_pipeline()))
    sandbox.client.delete_pipeline(sandbox.pipeline_repo_name)
    assert len(list(sandbox.client.list_pipeline())) == orig_pipeline_count - 1


def test_delete_all_pipelines():
    sandbox = Sandbox("delete_all_pipelines")
    sandbox.client.delete_all_pipelines()
    pipelines = list(sandbox.client.list_pipeline())
    assert len(pipelines) == 0


def test_restart_pipeline():
    sandbox = Sandbox("restart_job")

    sandbox.client.stop_pipeline(sandbox.pipeline_repo_name)
    pipeline = list(sandbox.client.inspect_pipeline(sandbox.pipeline_repo_name))[0]
    assert pipeline.stopped

    sandbox.client.start_pipeline(sandbox.pipeline_repo_name)
    pipeline = list(sandbox.client.inspect_pipeline(sandbox.pipeline_repo_name))[0]
    assert not pipeline.stopped


def test_run_cron():
    sandbox = Sandbox("run_cron")

    # flush the job so it fully finishes
    list(sandbox.client.wait_commit(sandbox.commit.id))

    # this should trigger an error because the sandbox pipeline doesn't have a
    # cron input
    # NOTE: `e` is used after the context
    with pytest.raises(python_pachyderm.RpcError, match=r"pipeline.*have a cron input"):
        sandbox.client.run_cron(sandbox.pipeline_repo_name)


def test_secrets():
    client = python_pachyderm.Client()
    secret_name = util.test_repo_name("test-secrets")

    client.create_secret(
        secret_name,
        {
            "mykey": "my-value",
        },
    )

    secret = client.inspect_secret(secret_name)
    assert secret.secret.name == secret_name

    secrets = client.list_secret()
    assert len(secrets) == 1
    assert secrets[0].secret.name == secret_name

    client.delete_secret(secret_name)

    with pytest.raises(python_pachyderm.RpcError):
        client.inspect_secret(secret_name)

    secrets = client.list_secret()
    assert len(secrets) == 0


def test_get_pipeline_logs():
    sandbox = Sandbox("get_pipeline_logs")
    sandbox.wait()
    # sleep 10 secs to wait for the k8s pod to be ready
    # TODO remove this sleep once we figure out why this test is broken
    # time.sleep(10)

    # Just make sure these spit out some logs
    logs = sandbox.client.get_pipeline_logs(sandbox.pipeline_repo_name)
    assert next(logs) is not None

    logs = sandbox.client.get_pipeline_logs(sandbox.pipeline_repo_name, master=True)
    assert next(logs) is not None


def test_get_job_logs():
    sandbox = Sandbox("get_logs_logs")
    job_id = sandbox.wait()
    pipeline_name = sandbox.pipeline_repo_name

    # Wait for the job to complete
    commit = (pipeline_name, job_id)
    sandbox.client.wait_commit(commit)

    # Just make sure these spit out some logs
    logs = sandbox.client.get_job_logs(pipeline_name, job_id)
    assert next(logs) is not None


def test_create_pipeline():
    client = python_pachyderm.Client()
    client.delete_all()

    input_repo_name = util.create_test_repo(client, "input_repo_test_create_pipeline")

    client.create_pipeline(
        "pipeline_test_create_pipeline",
        transform=pps_proto.Transform(
            cmd=["sh"],
            image="alpine",
            stdin=["cp /pfs/{}/*.dat /pfs/out/".format(input_repo_name)],
        ),
        input=pps_proto.Input(pfs=pps_proto.PFSInput(glob="/*", repo=input_repo_name)),
    )
    assert len(list(client.list_pipeline())) == 1


def test_create_pipeline_from_request():
    client = python_pachyderm.Client()

    repo_name = util.create_test_repo(client, "test_create_pipeline_from_request")
    pipeline_name = util.test_repo_name("test_create_pipeline_from_request")

    # more or less a copy of the opencv demo's edges pipeline spec
    client.create_pipeline_from_request(
        pps_proto.CreatePipelineRequest(
            pipeline=pps_proto.Pipeline(name=pipeline_name),
            description="A pipeline that performs image edge detection by using the OpenCV library.",
            input=pps_proto.Input(
                pfs=pps_proto.PFSInput(
                    glob="/*",
                    repo=repo_name,
                ),
            ),
            transform=pps_proto.Transform(
                cmd=["echo", "hi"],
                image="pachyderm/opencv",
            ),
        )
    )

    assert any(p.pipeline.name == pipeline_name for p in list(client.list_pipeline()))



#!/usr/bin/env python

"""Tests PFS-related functionality"""

import pytest
import tempfile
from io import BytesIO

import python_pachyderm
from python_pachyderm.service import pfs_proto
from tests import util


def sandbox(test_name):
    client = python_pachyderm.Client()
    repo_name = util.create_test_repo(client, test_name)
    return client, repo_name


def test_inspect_repo():
    client, repo_name = sandbox("inspect_repo")
    client.inspect_repo(repo_name)
    repos = list(client.list_repo())
    assert len(repos) >= 1
    assert repo_name in [r.repo.name for r in repos]


def test_delete_repo():
    client, repo_name = sandbox("delete_repo")
    orig_repo_count = len(list(client.list_repo()))
    assert orig_repo_count >= 1
    client.delete_repo(repo_name)
    assert len(list(client.list_repo())) == orig_repo_count - 1


def test_delete_non_existent_repo():
    client = python_pachyderm.Client()
    orig_repo_count = len(list(client.list_repo()))
    client.delete_repo("BOGUS_NAME")
    assert len(list(client.list_repo())) == orig_repo_count


def test_delete_all_repos():
    client = python_pachyderm.Client()

    util.create_test_repo(client, "test_delete_all_repos", prefix="extra-1")
    util.create_test_repo(client, "test_delete_all_repos", prefix="extra-2")
    assert len(list(client.list_repo())) >= 2

    client.delete_all_repos()
    assert len(list(client.list_repo())) == 0


def test_start_commit():
    client, repo_name = sandbox("start_commit")

    commit = client.start_commit(repo_name, "master")
    assert commit.branch.repo.name == repo_name

    # cannot start new commit before the previous one is finished
    with pytest.raises(
        python_pachyderm.RpcError, match=r"parent commit .* has not been finished"
    ):
        client.start_commit(repo_name, "master")

    client.finish_commit(commit)
    commit2 = client.start_commit(repo_name, "master")
    assert commit2.branch.repo.name == repo_name

    with pytest.raises(python_pachyderm.RpcError, match=r"repo .* not found"):
        client.start_commit("some-fake-repo", "master")


def test_start_commit_on_branch_with_parent():
    client, repo_name = sandbox("start_commit_on_branch_with_parent")

    commit1 = client.start_commit(repo_name, branch="master")
    client.finish_commit(commit1)

    commit2 = client.start_commit(repo_name, branch="master", parent=commit1.id)
    assert commit2.branch.repo.name == repo_name


def test_start_commit_fork():
    client, repo_name = sandbox("start_commit_fork")

    commit1 = client.start_commit(repo_name, branch="master")
    client.finish_commit((repo_name, commit1.id))

    commit2 = client.start_commit(repo_name, branch="patch", parent="master")

    assert commit2.branch.repo.name == repo_name

    branches = [
        branch_info.branch.name for branch_info in list(client.list_branch(repo_name))
    ]
    assert "master" in branches
    assert "patch" in branches


@pytest.mark.parametrize(
    "commit_arg",
    [
        "commit_obj",
        "(repo, commit_id)",
        "(repo, branch)",
        "(repo, branch, commit_id)",
        "(repo, branch, commit_id, type)",
        "dictionary",
    ],
)
def test_finish_commit(commit_arg):
    client, repo_name = sandbox("finish_commit")
    commit = client.start_commit(repo_name, "master")

    if commit_arg == "commit_obj":
        client.finish_commit(commit)
    elif commit_arg == "(repo, commit_id)":
        client.finish_commit((repo_name, commit.id))
    elif commit_arg == "(repo, branch)":
        client.finish_commit((repo_name, "master"))
    elif commit_arg == "(repo, branch, commit_id)":
        client.finish_commit((repo_name, "master", commit.id))
    elif commit_arg == "(repo, branch, commit_id, type)":
        client.finish_commit((repo_name, "master", commit.id, "user"))
    elif commit_arg == "dictionary":
        client.finish_commit({"repo": repo_name, "id": commit.id, "branch": "master"})

    client.wait_commit(commit)
    commit_infos = list(client.list_commit(repo_name))
    assert len(commit_infos) == 1
    assert commit_infos[0].commit.id == commit.id

    commit_match_count = len(
        [
            c
            for c in commit_infos
            if c.commit.id == commit.id and c.finished.seconds != 0
        ]
    )
    assert commit_match_count == 1
    assert commit_infos[0].finished.seconds != 0
    assert commit_infos[0].finished.nanos != 0


def test_commit_context_mgr():
    """Start and finish a commit using a context manager."""

    client, repo_name = sandbox("commit_context_mgr")

    with client.commit(repo_name, "master") as c1:
        pass
    with client.commit(repo_name, "master") as c2:
        pass

    with pytest.raises(python_pachyderm.RpcError):
        with client.commit("some-fake-repo", "master"):
            pass

    commit_infos = list(client.list_commit(repo_name))
    assert len(commit_infos) == 2
    assert sorted([c.commit.id for c in commit_infos]) == sorted([c1.id, c2.id])


def test_put_file_bytes_bytestring():
    """
    Start and finish a commit using a context manager while putting a file
    from a bytesting.
    """

    client, repo_name = sandbox("put_file_bytes_bytestring")

    with client.commit(repo_name, "master") as c:
        client.put_file_bytes(c, "file.dat", b"DATA")

    commit_infos = list(client.list_commit(repo_name))
    assert len(commit_infos) == 1
    assert commit_infos[0].commit.id == c.id
    files = list(client.list_file((repo_name, c.id), ""))
    assert len(files) == 1


def test_put_file_bytes_filelike():
    """
    Start and finish a commit using a context manager while putting a file
    from a file-like object.
    """

    client, repo_name = sandbox("put_file_bytes_filelike")

    with client.commit(repo_name, "master") as commit:
        client.put_file_bytes(commit, "file.dat", BytesIO(b"DATA"))

    files = list(client.list_file(commit, ""))
    assert len(files) == 1


def test_put_file_zero_bytes_pfc():
    """
    Put a zero-byte file using PutFileClient
    """

    client, repo_name = sandbox("put_file_bytes_file_zero_byte")

    commit = (repo_name, "master")
    with client.modify_file_client(commit) as c:
        c.put_file_from_bytes("file.dat", b"")
    files = list(client.list_file(commit, "/"))
    assert len(files) == 1
    fi = client.inspect_file(commit, "file.dat")
    assert fi.size_bytes == 0


def test_put_file_bytes_zero_bytes_direct():
    """
    Put a zero-byte file using a bytestring
    """

    client, repo_name = sandbox("put_file_bytes_zero_bytes")

    with client.commit(repo_name, "master") as c:
        client.put_file_bytes(c, "empty_bytestring.dat", b"")
    commit_infos = list(client.list_commit(repo_name))
    assert len(commit_infos) == 1
    assert commit_infos[0].commit.id == c.id
    fi = client.inspect_file(c, "empty_bytestring.dat")
    assert fi.size_bytes == 0


def test_put_file_bytes_large():
    """
    Put a file larger than the maximum message size.
    """

    client, repo_name = sandbox("put_file_bytes_large")

    with client.commit(repo_name, "master") as c:
        client.put_file_bytes(c, "file.dat", b"#" * (21 * 1024 * 1024))

    commit_infos = list(client.list_commit(repo_name))
    assert len(commit_infos) == 1
    assert commit_infos[0].commit.id == c.id
    files = list(client.list_file(c, ""))
    assert len(files) == 1


def test_put_file_url():
    client, repo_name = sandbox("put_file_url")

    with client.commit(repo_name, "master") as c:
        client.put_file_url(
            c,
            "index.html",
            "https://gist.githubusercontent.com/ysimonson/1986773831f6c4c292a7290c5a5d4405/raw/fb2b4d03d317816e36697a6864a9c27645baa6c0/wheel.html",
        )

    files = list(client.list_file(c, ""))
    assert len(files) == 1
    assert files[0].file.path == "/index.html"


def test_put_file_empty():
    client, repo_name = sandbox("put_file_atomic")
    commit = (repo_name, "master")

    with tempfile.NamedTemporaryFile() as f:
        with client.modify_file_client(commit) as pfc:
            pfc.put_file_from_fileobj("file1.dat", BytesIO(b""))
            pfc.put_file_from_url(
                "index.html",
                "https://gist.githubusercontent.com/ysimonson/1986773831f6c4c292a7290c5a5d4405/raw/fb2b4d03d317816e36697a6864a9c27645baa6c0/wheel.html",
            )
            pfc.put_file_from_bytes("file2.dat", b"DATA2")

            f.write(b"DATA3")
            f.flush()
            pfc.put_file_from_filepath("file3.dat", f.name)

    files = list(client.list_file(commit, ""))
    # assert len(files) == 4
    assert files[0].file.path == "/file1.dat"
    assert files[1].file.path == "/file2.dat"
    assert files[2].file.path == "/file3.dat"
    assert files[3].file.path == "/index.html"


def test_put_file_atomic():
    client, repo_name = sandbox("put_file_atomic")
    commit = (repo_name, "master")

    with tempfile.NamedTemporaryFile() as f:
        with client.modify_file_client(commit) as pfc:
            pfc.put_file_from_fileobj("file1.dat", BytesIO(b"DATA1"))
            pfc.put_file_from_bytes("file2.dat", b"DATA2")
            pfc.put_file_from_url(
                "index.html",
                "https://gist.githubusercontent.com/ysimonson/1986773831f6c4c292a7290c5a5d4405/raw/fb2b4d03d317816e36697a6864a9c27645baa6c0/wheel.html",
            )

            f.write(b"DATA3")
            f.flush()
            pfc.put_file_from_filepath("file3.dat", f.name)

    files = list(client.list_file(commit, ""))
    assert len(files) == 4
    assert files[0].file.path == "/file1.dat"
    assert files[1].file.path == "/file2.dat"
    assert files[2].file.path == "/file3.dat"
    assert files[3].file.path == "/index.html"

    with client.modify_file_client(commit) as pfc:
        pfc.delete_file("/file1.dat")
        pfc.delete_file("/file2.dat")
        pfc.delete_file("/file3.dat")

    files = list(client.list_file(commit, ""))
    assert len(files) == 1
    assert files[0].file.path == "/index.html"


def test_get_file():
    client, repo_name = sandbox("put_file_atomic")
    commit = (repo_name, "master")

    with client.modify_file_client(commit) as pfc:
        pfc.put_file_from_fileobj("file1.dat", BytesIO(b"DATA1"))

    assert client.get_file(commit, "file1.dat").read() == b"DATA1"


def test_get_file_tar():
    client, repo_name = sandbox("put_file_atomic")
    commit = (repo_name, "master")

    with client.modify_file_client(commit) as pfc:
        pfc.put_file_from_fileobj("file1.dat", BytesIO(b"DATA1"))

    assert client.get_file_tar(commit, "file1.dat").read() == b"DATA1"


def test_PFSFile_iter():
    client, repo_name = sandbox("put_file_atomic")
    commit = (repo_name, "master")

    with client.modify_file_client(commit) as pfc:
        pfc.put_file_from_fileobj("file1.dat", BytesIO(b"DATA1"))

    assert list(client.get_file(commit, "file1.dat"))[0] == b"DATA1"


def test_copy_file():
    client, repo_name = sandbox("copy_file")

    with client.commit(repo_name, "master") as src_commit:
        client.put_file_bytes(src_commit, "file1.dat", BytesIO(b"DATA1"))
        client.put_file_bytes(src_commit, "file2.dat", BytesIO(b"DATA2"))

    with client.commit(repo_name, "master") as dest_commit:
        client.copy_file(src_commit, "file1.dat", dest_commit, "copy.dat")

    files = list(client.list_file(dest_commit, ""))
    assert len(files) == 3
    assert files[0].file.path == "/copy.dat"
    assert files[1].file.path == "/file1.dat"
    assert files[2].file.path == "/file2.dat"


def test_wait_commit():
    """
    Ensure wait_commit works
    """
    client, repo_name = sandbox("wait_commit")
    repo2_name = util.create_test_repo(client, "wait_commit2")

    # Create provenance between repos (which creates a new commit)
    client.create_branch(
        repo2_name,
        "master",
        provenance=[
            pfs_proto.Branch(
                repo=pfs_proto.Repo(name=repo_name, type="user"), name="master"
            )
        ],
    )
    # Head commit is still open in repo2
    client.finish_commit((repo2_name, "master"))

    with client.commit(repo_name, "master") as c:
        client.put_file_bytes(c, "input.json", b"hello world")
    client.finish_commit((repo2_name, "master"))

    # Just block until all of the commits are yielded
    commits = client.wait_commit(c.id)
    assert len(commits) == 2
    assert commits[1].finished

    with client.commit(repo_name, "master") as c2:
        client.put_file_bytes(c2, "input.json", b"bye world")
    client.finish_commit((repo2_name, "master"))

    # Just block until the commit in repo1 is finished
    commits = client.wait_commit(c2)
    assert len(commits) == 1
    assert commits[0].finished

    files = list(client.list_file(c2, "/"))
    assert len(files) == 1


def test_inspect_commit():
    client, repo_name = sandbox("inspect_commit")
    repo2_name = util.create_test_repo(client, "inspect_commit2")

    # Create provenance between repos (which creates a new commit)
    client.create_branch(
        repo2_name,
        "master",
        provenance=[
            pfs_proto.Branch(
                repo=pfs_proto.Repo(name=repo_name, type="user"), name="master"
            )
        ],
    )
    # Head commit is still open in repo2
    client.finish_commit((repo2_name, "master"))

    with client.commit(repo_name, "master") as c:
        client.put_file_bytes(c, "input.json", b"hello world")
    client.finish_commit((repo2_name, "master"))

    # Inspect commit at a specific repo
    commits = list(client.inspect_commit(c, pfs_proto.CommitState.FINISHED))
    assert len(commits) == 1

    commit = commits[0]
    assert commit.commit.branch.name == "master"
    assert commit.finished
    assert commit.description == ""
    # assert commit.size_bytes == 11
    assert len(commit.commit.id) == 32
    assert commit.commit.branch.repo.name == repo_name

    # Inspect entire commit
    commits = list(client.inspect_commit(c.id, pfs_proto.CommitState.FINISHED))
    assert len(commits) == 2


def test_squash_commit():
    client, repo_name = sandbox("squash_commit")
    repo2_name = util.create_test_repo(client, "squash_commit2")

    # Create provenance between repos (which creates a new commit)
    client.create_branch(
        repo2_name,
        "master",
        provenance=[
            pfs_proto.Branch(
                repo=pfs_proto.Repo(name=repo_name, type="user"), name="master"
            )
        ],
    )
    # Head commit is still open in repo2
    client.finish_commit((repo2_name, "master"))

    with client.commit(repo_name, "master") as commit1:
        pass
    client.finish_commit((repo2_name, "master"))

    with client.commit(repo_name, "master") as commit2:
        pass
    client.finish_commit((repo2_name, "master"))

    commits = list(client.list_commit(repo_name))
    assert len(commits) == 3
    client.wait_commit(commit2.id)
    client.squash_commit(commit1.id)
    commits = list(client.list_commit(repo_name))
    assert len(commits) == 2
    commits = list(client.list_commit(repo2_name))
    assert len(commits) == 2


def test_drop_commit():
    client, repo_name = sandbox("drop_commit")
    repo2_name = util.create_test_repo(client, "drop_commit2")

    # Create provenance between repos (which creates a new commit)
    client.create_branch(
        repo2_name,
        "master",
        provenance=[
            pfs_proto.Branch(
                repo=pfs_proto.Repo(name=repo_name, type="user"), name="master"
            )
        ],
    )
    # Head commit is still open in repo2
    client.finish_commit((repo2_name, "master"))

    with client.commit(repo_name, "master"):
        pass
    client.finish_commit((repo2_name, "master"))

    with client.commit(repo_name, "master") as commit2:
        pass
    client.finish_commit((repo2_name, "master"))

    commits = list(client.list_commit(repo_name))
    assert len(commits) == 3
    client.wait_commit(commit2.id)
    client.drop_commit(commit2.id)
    commits = list(client.list_commit(repo_name))
    assert len(commits) == 2
    commits = list(client.list_commit(repo2_name))
    assert len(commits) == 2


def test_subscribe_commit():
    client, repo_name = sandbox("subscribe_commit")
    commits = client.subscribe_commit(repo_name, "master")

    with client.commit(repo_name, "master"):
        pass

    commit = next(commits)
    assert commit.commit.branch.repo.name == repo_name
    assert commit.commit.branch.name == "master"


def test_list_commit():
    python_pachyderm.Client().delete_all_repos()

    client, repo_name1 = sandbox("list_commit1")

    with client.commit(repo_name1, "master"):
        pass
    with client.commit(repo_name1, "master"):
        pass

    repo_name2 = util.create_test_repo(client, "list_commit2")

    with client.commit(repo_name2, "master"):
        pass

    commits = list(client.list_commit())
    assert len(commits) == 3


def test_list_branch():
    client, repo_name = sandbox("list_branch")

    with client.commit(repo_name, "master"):
        pass
    with client.commit(repo_name, "develop"):
        pass

    branches = list(client.list_branch(repo_name))
    assert len(branches) == 2
    assert branches[0].branch.name == "develop"
    assert branches[1].branch.name == "master"


def test_delete_branch():
    client, repo_name = sandbox("delete_branch")

    with client.commit(repo_name, "develop"):
        pass

    branches = list(client.list_branch(repo_name))
    assert len(branches) == 1
    client.delete_branch(repo_name, "develop")
    branches = list(client.list_branch(repo_name))
    assert len(branches) == 0


def test_inspect_file():
    client, repo_name = sandbox("inspect_file")

    with client.commit(repo_name, "master") as c:
        client.put_file_bytes(c, "file.dat", b"DATA")

    fi = client.inspect_file(c, "file.dat")
    assert fi.file.commit.id == c.id
    assert fi.file.commit.branch.repo.name == repo_name
    assert fi.file.path == "/file.dat"
    # assert fi.size_bytes == 4


def test_list_file():
    client, repo_name = sandbox("list_file")

    with client.commit(repo_name, "master") as c:
        client.put_file_bytes(c, "file1.dat", b"DATA")
        client.put_file_bytes(c, "file2.dat", b"DATA")

    files = list(client.list_file((repo_name, c.id), "/"))
    assert len(files) == 2
    # assert files[0].size_bytes == 4
    assert files[0].file_type == pfs_proto.FileType.FILE
    assert files[0].file.path == "/file1.dat"
    # assert files[1].size_bytes == 4
    assert files[1].file_type == pfs_proto.FileType.FILE
    assert files[1].file.path == "/file2.dat"


def test_walk_file():
    client, repo_name = sandbox("walk_file")

    with client.commit(repo_name, "master") as c:
        client.put_file_bytes(c, "/file1.dat", b"DATA")
        client.put_file_bytes(c, "/a/file2.dat", b"DATA")
        client.put_file_bytes(c, "/a/b/file3.dat", b"DATA")

    files = list(client.walk_file(c, "/a"))
    assert len(files) == 4
    assert files[0].file.path == "/a/"
    assert files[1].file.path == "/a/b/"
    assert files[2].file.path == "/a/b/file3.dat"
    assert files[3].file.path == "/a/file2.dat"


def test_glob_file():
    client, repo_name = sandbox("glob_file")

    with client.commit(repo_name, "master") as c:
        client.put_file_bytes(c, "file1.dat", b"DATA")
        client.put_file_bytes(c, "file2.dat", b"DATA")

    files = list(client.glob_file(c, "/*.dat"))
    assert len(files) == 2
    # assert files[0].size_bytes == 4
    assert files[0].file_type == pfs_proto.FileType.FILE
    assert files[0].file.path == "/file1.dat"
    # assert files[1].size_bytes == 4
    assert files[1].file_type == pfs_proto.FileType.FILE
    assert files[1].file.path == "/file2.dat"

    files = list(client.glob_file(c, "/*1.dat"))
    assert len(files) == 1
    # assert files[0].size_bytes == 4
    assert files[0].file_type == pfs_proto.FileType.FILE
    assert files[0].file.path == "/file1.dat"


def test_delete_file():
    client, repo_name = sandbox("delete_file")

    with client.commit(repo_name, "master") as c:
        client.put_file_bytes(c, "file1.dat", b"DATA")

    assert len(list(client.list_file(c, "/"))) == 1

    with client.commit(repo_name, "master") as c:
        client.delete_file(c, "file1.dat")

    assert len(list(client.list_file(c, "/"))) == 0


def test_create_branch():
    client, repo_name = sandbox("create_branch")
    client.create_branch(repo_name, "foobar")
    branches = list(client.list_branch(repo_name))
    assert len(branches) == 1
    assert branches[0].branch.name == "foobar"


def test_inspect_branch():
    client, repo_name = sandbox("inspect_branch")
    client.create_branch(repo_name, "foobar")
    branch = client.inspect_branch(repo_name, "foobar")
    assert branch.branch.name == "foobar"


def test_fsck():
    client = python_pachyderm.Client()
    assert len(list(client.fsck())) == 0


def test_diff_file():
    client, repo_name = sandbox("diff_file")

    with client.commit(repo_name, "master") as old_commit:
        client.put_file_bytes(old_commit, "file1.dat", BytesIO(b"old data 1"))
        client.put_file_bytes(old_commit, "file2.dat", BytesIO(b"old data 2"))

    with client.commit(repo_name, "master") as new_commit:
        client.put_file_bytes(new_commit, "file1.dat", BytesIO(b"new data 1"))

    diff = list(client.diff_file(new_commit, "file1.dat", old_commit, "file2.dat"))
    assert diff[0].new_file.file.path == "/file1.dat"
    assert diff[1].old_file.file.path == "/file2.dat"



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from python_pachyderm.proto.v2.transaction import transaction_pb2 as python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2


class APIStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.BatchTransaction = channel.unary_unary(
                '/transaction_v2.API/BatchTransaction',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.BatchTransactionRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.TransactionInfo.FromString,
                )
        self.StartTransaction = channel.unary_unary(
                '/transaction_v2.API/StartTransaction',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.StartTransactionRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.Transaction.FromString,
                )
        self.InspectTransaction = channel.unary_unary(
                '/transaction_v2.API/InspectTransaction',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.InspectTransactionRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.TransactionInfo.FromString,
                )
        self.DeleteTransaction = channel.unary_unary(
                '/transaction_v2.API/DeleteTransaction',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.DeleteTransactionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListTransaction = channel.unary_unary(
                '/transaction_v2.API/ListTransaction',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.ListTransactionRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.TransactionInfos.FromString,
                )
        self.FinishTransaction = channel.unary_unary(
                '/transaction_v2.API/FinishTransaction',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.FinishTransactionRequest.SerializeToString,
                response_deserializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.TransactionInfo.FromString,
                )
        self.DeleteAll = channel.unary_unary(
                '/transaction_v2.API/DeleteAll',
                request_serializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.DeleteAllRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class APIServicer(object):
    """Missing associated documentation comment in .proto file."""

    def BatchTransaction(self, request, context):
        """Transaction rpcs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartTransaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InspectTransaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteTransaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTransaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FinishTransaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAll(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_APIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'BatchTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchTransaction,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.BatchTransactionRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.TransactionInfo.SerializeToString,
            ),
            'StartTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.StartTransaction,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.StartTransactionRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.Transaction.SerializeToString,
            ),
            'InspectTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.InspectTransaction,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.InspectTransactionRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.TransactionInfo.SerializeToString,
            ),
            'DeleteTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteTransaction,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.DeleteTransactionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTransaction,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.ListTransactionRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.TransactionInfos.SerializeToString,
            ),
            'FinishTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.FinishTransaction,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.FinishTransactionRequest.FromString,
                    response_serializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.TransactionInfo.SerializeToString,
            ),
            'DeleteAll': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAll,
                    request_deserializer=python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.DeleteAllRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'transaction_v2.API', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class API(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def BatchTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/transaction_v2.API/BatchTransaction',
            python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.BatchTransactionRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.TransactionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/transaction_v2.API/StartTransaction',
            python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.StartTransactionRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.Transaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InspectTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/transaction_v2.API/InspectTransaction',
            python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.InspectTransactionRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.TransactionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/transaction_v2.API/DeleteTransaction',
            python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.DeleteTransactionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/transaction_v2.API/ListTransaction',
            python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.ListTransactionRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.TransactionInfos.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FinishTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/transaction_v2.API/FinishTransaction',
            python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.FinishTransactionRequest.SerializeToString,
            python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.TransactionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/transaction_v2.API/DeleteAll',
            python__pachyderm_dot_proto_dot_v2_dot_transaction_dot_transaction__pb2.DeleteAllRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
